models

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EnvFinding

type EnvFinding struct {
	EnvKey      string
	EnvValue    string
	Description string
}

EnvFinding represents a secret found in an environment variable

type Namespace

type Namespace struct {
	Type  string
	Inode uint32
}

Namespace contains all the fields relevant to a namespace

type Process

type Process struct {
	Command    string
	PID        int
	PPID       int
	Namespaces []*Namespace
}

Process contains all the fields relevant to a process

type ProxyConfig

type ProxyConfig struct {
	HTTPProxy  string
	HTTPSProxy string
	ALLProxy   string
	NoProxy    string
	SOCKSProxy string
	PACURL     string
}

ProxyConfig contains all the fields with information about the proxy

type UserIdentity

type UserIdentity struct {
	UID    int
	GID    int
	EUID   int
	EGID   int
	Groups []int
}

UserIdentity contains all the fields with information about user and its groups

Jump to