The highest tagged major version is
v6.
package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: May 18, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
EnvFinding represents a secret found in an environment variable
Namespace contains all the fields relevant to a namespace
Process contains all the fields relevant to a process
ProxyConfig contains all the fields with information about the proxy
type UserIdentity struct {
UID int
GID int
EUID int
EGID int
Groups []int
}
UserIdentity contains all the fields with information about user and its groups
Source Files
¶
Click to show internal directories.
Click to hide internal directories.